@@ -96,6 +96,7 @@ bool IOAudioControlUserClient::initWithAudioControl(IOAudioControl *control, tas
     }
 
     audioControl = control;
+	audioControl->retain();
     clientTask = task;
     notificationMessage = 0;
 
@@ -122,8 +123,11 @@ IOReturn IOAudioControlUserClient::clientClose()
     IOLog("IOAudioControlUserClient[%p]::clientClose()\n", this);
 #endif
 
-    if (audioControl && !isInactive()) {
-        audioControl->clientClosed(this);
+    if (audioControl) {
+		if (!audioControl->isInactive () && !isInactive()) {
+			audioControl->clientClosed(this);
+		}
+		audioControl->release();
         audioControl = 0;
     }
     
