@@ -69,6 +69,7 @@
 
 #define kIOAudioDeviceTransportTypeKey		"IOAudioDeviceTransportType"
 
+#define kIOAudioDeviceConfigurationAppKey	"IOAudioDeviceConfigurationApplication"
 
 
 /*****
@@ -109,6 +110,27 @@
 
 #define kIOAudioEngineDescriptionKey				"IOAudioEngineDescription"
 
+/*!
+ * @defined kIOAudioEngineFullChannelNamesKey
+ * @abstract The key in the IORegistry for the IOAudioEngine's dictionary of fully constructed names for each channel keyed by the device channel
+ * @discussion 
+ */
+#define	kIOAudioEngineFullChannelNamesKey			"IOAudioEngineChannelNames"
+
+/*!
+ * @defined kIOAudioEngineFullChannelNamesKey
+ * @abstract The key in the IORegistry for the IOAudioEngine's dictionary of category names for each channel keyed by the device channel
+ * @discussion 
+ */
+#define	kIOAudioEngineFullChannelCategoryNamesKey	"IOAudioEngineChannelCategoryNames"
+
+/*!
+ * @defined kIOAudioEngineFullChannelNamesKey
+ * @abstract The key in the IORegistry for the IOAudioEngine's dictionary of number names for each channel keyed by the device channel
+ * @discussion 
+ */
+#define	kIOAudioEngineFullChannelNumberNamesKey		"IOAudioEngineChannelNumberNames"
+
 /*****
  *
  * IOAudioStream defines
@@ -220,7 +242,7 @@
  */
 #define kIOAudioControlChannelIDKey		"IOAudioControlChannelID"
 
-#define kIOAudioControlChannelNumberKey	"IOAudioControlChannelNumber"
+#define kIOAudioControlChannelNumberKey			"IOAudioControlChannelNumber"
 
 #define kIOAudioControlCoreAudioPropertyIDKey	"IOAudioControlCoreAudioPropertyID"
 /*!
@@ -289,6 +311,14 @@
  */
 #define kIOAudioControlValueKey				"IOAudioControlValue"
 
+/*!
+ * @defined kIOAudioControlValueIsReadOnlyKey
+ * @abstract The key in the IORegistry for the IOAudioControl value-is-read-only attribute.
+ * @discussion The value returned by this key is a 32-bit integer but the value doesn't have any direct meaning.
+ *  Instead, the presence of this key indicates that the value for the control is read-only
+ */
+#define kIOAudioControlValueIsReadOnlyKey	"IOAudioControlValueIsReadOnly"
+
 /*!
  * @defined kIOAudioLevelControlMinValueKey
  * @abstract The key in the IORegistry for the IOAudioControl minimum value attribute.
