@@ -213,7 +213,9 @@ protected:
     bool			deviceStartedAudioEngine;
     
 protected:
-    struct ExpansionData { };
+    struct ExpansionData {
+		UInt32		pauseCount;
+	};
     
     ExpansionData *reserved;
 
@@ -472,7 +474,26 @@ public:
     virtual IOReturn pauseAudioEngine();
     virtual IOReturn resumeAudioEngine();
     
+    /*!
+     * @function performAudioEngineStart
+     * @abstract Called to start the audio I/O engine
+     * @discussion This method is called by startAudioEngine().  This must be overridden by the subclass.
+	 *	No call to the superclass' implementation is necessary.  The subclass' implementation must start up the
+	 *	audio I/O engine.  This includes any audio engine that needs to be started as well as any interrupts
+	 *	that need to be enabled.
+     * @result Must return kIOReturnSuccess on a successful start of the engine.
+     */
     virtual IOReturn performAudioEngineStart();
+
+    /*!
+     * @function performAudioEngineStop
+     * @abstract Called to stop the audio I/O engine
+     * @discussion This method is called by stopAudioEngine() and pauseAudioEngine.
+     *  This must be overridden by the subclass.  No call to the superclass' implementation is
+     *  necessary.  The subclass' implementation must stop the audio I/O engine.  This includes any audio
+     *  engine that needs to be stopped as well as any interrupts that need to be disabled.
+     * @result Must return kIOReturnSuccess on a successful stop of the engine.
+     */
     virtual IOReturn performAudioEngineStop();
 
     /*! 
